breed [micropollutants micropollutant]
breed [larvae larva]
breed [fishes fish]
breed [seals seal]
breed [sharks shark]

globals [
  new_micropollutants
  new_larvae
  new_fishes
  new_seals
  new_sharks
  micropollutants-consumed
  larvae-eaten
  fishes-eaten
  seals-eaten]

patches-own [
  height_micropollutants
  height_larvae
  height_fishes
  height_seals
  height_sharks
]

to setup
  clear-all
  setup-patches
  setup-micropollutants
  setup-larvae
  setup-fishes
  setup-seals
  setup-sharks
  set micropollutants-consumed 0
  set larvae-eaten 0
  reset-ticks
end

to setup-patches
  ask patches [
    set pcolor cyan + (random-float 0.8) - 0.4 ; background variation to achieve more realistic water ecosystem setting
  ]
end

to setup-micropollutants
  create-micropollutants number_micropollutants ; create amount of micropollutants dictated by micropollutant slider
  ask micropollutants [
    set shape "dot"
    set color black
    set size 1 ; smallest of the breeds
    setxy random-xcor random-ycor ; begin at random location within world
  ]
end

to setup-larvae
  create-larvae number_larvae ; create amount of larvae dictated by larvae slider
  ask larvae [
    set shape "caterpillar" ; closest form to larvae of options in library
    set color 44 ; dark yellow
    set size 4 ; larger than micropollutants and smaller than other breeds
    setxy random-xcor random-ycor ; begin at random location within world
  ]
end

to setup-fishes
  create-fishes number_fish ; create amount of fish dictated by fish slider
  ask fishes [
    set shape "fish 2"
    set color 116 ; dark purple
    set size 5 ; larger than larvae, smaller than seals and sharks
    setxy random-xcor random-ycor ; begin at random location within world
  ]
end

to setup-seals
  create-seals number_seals ; create amount of seals dictated by seal slider
  ask seals [
    set shape "bird side" ; closes resemblance to seal of library options
    set color 24 ; dark orange
    set size 12 ; larger than fish, smaller than shark
    setxy random-xcor random-ycor ; begin at random location within world
  ]
end

to setup-sharks
  create-sharks number_sharks ; create amount of sharks dictated by shark slider
  ask sharks [
    set shape "shark"
    set color 4 ; dark gray
    set size 20 ; largest of the breeds
    setxy random-xcor random-ycor ; begin at random location within world
  ]
end

to add-micropollutants ; button to add more micropollutants based on amount dictated by slider
  set new_micropollutants 1
end

to add-larvae ; button to add more larvae based on amount dictated by slider
  set new_larvae 1
end

to add-fishes ; button to add more fish based on amount dictated by slider
  set new_fishes 1
end

to add-seals ; button to add more seals based on amount dictated by slider
  set new_seals 1
end

to add-sharks ; button to add more sharks based on amount dictated by slider
  set new_sharks 1
end

to go
  check-new_micropollutants
  check-new_larvae
  check-new_fishes
  check-new_seals
  check-new_sharks
  move-micropollutants
  update-patches
  move-larvae
  move-fishes
  move-seals
  move-sharks
  eat-micropollutants
  eat-larvae
  eat-fishes
  eat-seals
  tick
end

to check-new_micropollutants
  if new_micropollutants = 1 [
    create-micropollutants number_micropollutants
    ask micropollutants [
      set shape "dot"
      set color black
      set size 1
      setxy random-xcor random-ycor
    ]
  ]
  set new_micropollutants 0
end

to check-new_larvae
  if new_larvae = 1 [
    create-larvae number_larvae
    ask larvae [
      set shape "caterpillar"
      set color 44
      set size 4
      setxy random-xcor random-ycor
    ]
  ]
  set new_larvae 0
end

to check-new_fishes
  if new_fishes = 1 [
    create-fishes number_fish
    ask fishes [
      set shape "fish 2"
      set color 116
      set size 5
      setxy random-xcor random-ycor
    ]
  ]
  set new_fishes 0
end

to check-new_seals
  if new_seals = 1 [
    create-seals number_seals
    ask seals [
      set shape "bird side"
      set color 24
      set size 12
      setxy random-xcor random-ycor
    ]
  ]
  set new_seals 0
end

to check-new_sharks
  if new_sharks = 1 [
    create-sharks number_sharks
    ask sharks [
      set shape "shark"
      set color 4
      set size 20
      setxy random-xcor random-ycor
    ]
  ]
  set new_sharks 0
end

to move-micropollutants
  ask micropollutants [
    right random 360 ; random movement
    forward 0.5 ; slowest movement of breeds
    ask patch-here [
      set height_micropollutants 1 ; smallest height of all breeds
    ]
  ]
end

to update-patches
  diffuse height_micropollutants 0.8 ; most rapid height diffusion, shortest spread
  diffuse height_larvae 0.6 ; more rapid height than fish, more gradual height than micropollutants
  diffuse height_fishes 0.4 ; more rapid height than seals, more gradual height than larvae
  diffuse height_seals 0.2 ; more rapid height than sharks, more gradual height than fish
  diffuse height_sharks 0.1 ; most gradual height difusion, greatest spread
end

to move-larvae
  ask larvae [
    uphill height_micropollutants ; move toward micropollutants (prey)
    downhill height_fishes ; move away from fish (predator)
    forward 1 / (micropollutants-consumed + 1) ; denominator cannot be zero for graph, reason for +1
    ask patch-here [
      set height_larvae 2 ; height greater than micropollutants but smaller than fish
    ]
  ]
end

to move-fishes
  ask fishes [
    uphill height_larvae ; move toward larvae (prey)
    downhill height_seals ; move away from seals (predator)
    forward 1 / (larvae-eaten + 1) ; denominator cannot be zero for graph, reason for +1
    ask patch-here [
      set height_fishes 3 ; height greater than larvae but smaller than seals
    ]
  ]
end

to move-seals
  ask seals [
    uphill height_fishes ; move toward fish (prey)
    downhill height_sharks ; move away from sharks (predator)
    forward 1 / (fishes-eaten + 1) ; denominator cannot be zero for graph, reason for +1
    ask patch-here [
      set height_seals 4 ; height greater than fish but smaller than shark
    ]
  ]
end

to move-sharks
  ask sharks [
    uphill height_seals ; move toward seals (prey), no predator to move away from
    forward 1 / (seals-eaten + 1) ; denominator cannot be zero for graph, reason for +1
    ask patch-here [
      set height_sharks 5 ; greatest height of breeds
    ]
  ]
end

to eat-micropollutants
  ask micropollutants [
    if count larvae-on neighbors > 0 [ ; if one or more larvae in neighboring eight patches
      set micropollutants-consumed micropollutants-consumed + 1 ; reduce micropollutant count by one
      die ; micropollutants die
    ]
  ]
end

to eat-larvae
  ask larvae [
    if count fishes-on neighbors > 0 [ ; if one or more fish in neighboring eight patches
      set larvae-eaten larvae-eaten + 1 ; reduce larvae count by one
      die ; larvae die
    ]
  ]
end

to eat-fishes
  ask fishes [
    if count seals-on neighbors > 0 [ ; if one or more seals in neighboring eight patches
      set fishes-eaten fishes-eaten + 1 ; reduce fish count by one
      die ; fish die
    ]
  ]
end

to eat-seals
  ask seals [
    if count sharks-on neighbors > 0 [ ; if one or more sharks in neighboring eight patches
      set seals-eaten seals-eaten + 1 ; reduce seal count by one
      die ; seals die
    ]
  ]
end





@#$#@#$#@
GRAPHICS-WINDOW
642
14
1142
535
50
50
4.8515
1
10
1
1
1
0
1
1
1
-50
50
-50
50
1
1
1
ticks
15.0

BUTTON
10
13
74
46
Setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
87
13
150
46
Go
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
0

BUTTON
163
13
242
46
Go Once
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
0

BUTTON
361
69
492
102
Add Micropollutant
add-micropollutants
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
11
69
344
102
number_micropollutants
number_micropollutants
0
1000
500
1
1
NIL
HORIZONTAL

MONITOR
13
328
223
373
Average Micropollutants Per Larvae
micropollutants-consumed / (count larvae + larvae-eaten)
17
1
11

MONITOR
13
381
224
426
Average Micropollutant Per Fish
larvae-eaten * micropollutants-consumed / (count larvae + larvae-eaten)
17
1
11

MONITOR
13
435
224
480
Average Micropollutant Per Seal
fishes-eaten * larvae-eaten * micropollutants-consumed / (count larvae + larvae-eaten)
17
1
11

MONITOR
14
490
224
535
Average Micropollutant Per Shark
seals-eaten * fishes-eaten * larvae-eaten * micropollutants-consumed / (count larvae + larvae-eaten)
17
1
11

SLIDER
12
120
344
153
number_larvae
number_larvae
0
100
50
1
1
NIL
HORIZONTAL

SLIDER
12
169
343
202
number_fish
number_fish
0
50
30
1
1
NIL
HORIZONTAL

SLIDER
12
220
343
253
number_seals
number_seals
0
10
6
1
1
NIL
HORIZONTAL

SLIDER
13
268
343
301
number_sharks
number_sharks
0
5
2
1
1
NIL
HORIZONTAL

BUTTON
361
120
491
153
Add Larvae
add-larvae
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
360
169
490
202
Add Fish
add-fishes
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
360
221
490
254
Add Seals
add-seals
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
361
269
490
302
Add Sharks
add-sharks
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
504
63
623
108
No. Micropollutants
count micropollutants
17
1
11

MONITOR
505
114
623
159
No. Larvae
count larvae
17
1
11

MONITOR
505
165
623
210
No. Fishes
count fishes
17
1
11

MONITOR
505
216
623
261
No. Seals
count seals
17
1
11

MONITOR
506
267
625
312
No. Sharks
count sharks
17
1
11

PLOT
239
327
626
535
Biomagnification/Bioaccumulation of Micropollutant
NIL
Micropollutant / Organism
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Larvae" 1.0 0 -13840069 true "" "plot micropollutants-consumed / (count larvae + larvae-eaten)"
"Fishes" 1.0 0 -8630108 true "" "plot larvae-eaten * micropollutants-consumed / (count larvae + larvae-eaten)"
"Seals" 1.0 0 -3844592 true "" "plot fishes-eaten * larvae-eaten * micropollutants-consumed / (count larvae + larvae-eaten)"
"Sharks" 1.0 0 -11053225 true "" "plot seals-eaten * fishes-eaten * larvae-eaten * micropollutants-consumed / (count larvae + larvae-eaten)"

@#$#@#$#@
## WHAT IS IT?

(a general understanding of what the model is trying to show or explain)

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

bird side
false
0
Polygon -7500403 true true 0 120 45 90 75 90 105 120 150 120 240 135 285 120 285 135 300 150 240 150 195 165 255 195 210 195 150 210 90 195 60 180 45 135
Circle -16777216 true false 38 98 14

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

caterpillar
true
0
Polygon -7500403 true true 165 210 165 225 135 255 105 270 90 270 75 255 75 240 90 210 120 195 135 165 165 135 165 105 150 75 150 60 135 60 120 45 120 30 135 15 150 15 180 30 180 45 195 45 210 60 225 105 225 135 210 150 210 165 195 195 180 210
Line -16777216 false 135 255 90 210
Line -16777216 false 165 225 120 195
Line -16777216 false 135 165 180 210
Line -16777216 false 150 150 201 186
Line -16777216 false 165 135 210 150
Line -16777216 false 165 120 225 120
Line -16777216 false 165 106 221 90
Line -16777216 false 157 91 210 60
Line -16777216 false 150 60 180 45
Line -16777216 false 120 30 96 26
Line -16777216 false 124 0 135 15

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

fish 2
false
0
Polygon -1 true false 56 133 34 127 12 105 21 126 23 146 16 163 10 194 32 177 55 173
Polygon -7500403 true true 156 229 118 242 67 248 37 248 51 222 49 168
Polygon -7500403 true true 30 60 45 75 60 105 50 136 150 53 89 56
Polygon -7500403 true true 50 132 146 52 241 72 268 119 291 147 271 156 291 164 264 208 211 239 148 231 48 177
Circle -1 true false 237 116 30
Circle -16777216 true false 241 127 12
Polygon -1 true false 159 228 160 294 182 281 206 236
Polygon -7500403 true true 102 189 109 203
Polygon -1 true false 215 182 181 192 171 177 169 164 152 142 154 123 170 119 223 163
Line -16777216 false 240 77 162 71
Line -16777216 false 164 71 98 78
Line -16777216 false 96 79 62 105
Line -16777216 false 50 179 88 217
Line -16777216 false 88 217 149 230

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

shark
false
0
Polygon -7500403 true true 283 153 288 149 271 146 301 145 300 138 247 119 190 107 104 117 54 133 39 134 10 99 9 112 19 142 9 175 10 185 40 158 69 154 64 164 80 161 86 156 132 160 209 164
Polygon -7500403 true true 199 161 152 166 137 164 169 154
Polygon -7500403 true true 188 108 172 83 160 74 156 76 159 97 153 112
Circle -16777216 true false 256 129 12
Line -16777216 false 222 134 222 150
Line -16777216 false 217 134 217 150
Line -16777216 false 212 134 212 150
Polygon -7500403 true true 78 125 62 118 63 130
Polygon -7500403 true true 121 157 105 161 101 156 106 152

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.3.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
